unit Rundun;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ComAbout, DsgnIntf;

type
  TRunDUNConnection = class(TComponent)
  private
    { Private declarations }
    FConnectionName: string;
    FAbout: string;
  protected
    { Protected declarations }
    {$IFDEF WIN32}
    procedure ValidateRename(AComponent: TComponent; const CurName, NewName: string);  override;
    {$ENDIF}
  public
    { Public declarations }
    function Execute: Boolean;
  published
    { Published declarations }
    property ConnectionName: string read FConnectionName write FConnectionName;
    property About: string read FAbout write FAbout;
  end;

  { AboutTypeProperty }

type
  TAboutTypeProperty = class(TPropertyEditor)
  private

  public
     function GetValue: string; override;
     procedure SetValue(const Value: string); override;
     procedure Edit; override;
     function GetAttributes: TPropertyAttributes; override;
  end;


var
   AboutIOPort: TAboutComponent;

procedure Register;
procedure RunAboutBox;

implementation

procedure Register;
begin
  RegisterComponents('BealeARTS', [TRunDUNConnection]);
  RegisterPropertyEditor(TypeInfo(string), TRunDUNConnection, 'About', TAboutTypeProperty);
end;


{$IFDEF WIN32}
procedure TRunDUNConnection.ValidateRename(AComponent: TComponent;
  const CurName, NewName: string);
begin
  if (AComponent <> nil) and (CompareText(CurName, NewName) <> 0) and
    (FindComponent(NewName) <> nil) then
    raise EComponentError.CreateFmt('A component named %s already exists.', [NewName]);
end;
{$ENDIF}


function TRunDUNConnection.Execute: Boolean;
var
   Text: array[0..255] of char;
begin
     StrPCopy(Text, 'rundll32.exe rnaui.dll,RnaDial ' + FConnectionName);
     if WinExec(Text,SW_SHOWNORMAL) < 32 then Result := False else Result := True;
end;




procedure RunAboutBox;
begin
 { Create dialog in memory }
     AboutIOPort := TAboutComponent.Create(Application);

     { Set dialog strings }
     AboutIOPort.ProductName.Font.Size := 16;
     AboutIOPort.ProductName.Caption := 'RunDUNConnection';
     AboutIOPort.Caption := 'About RunDUNConnection';
     AboutIOPort.Copyright.Caption := 'Copyright 1998, David Beale';

AboutIOPort.Memo.Lines.Add('Properties');
AboutIOPort.Memo.Lines.Add('_______________________________________________');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('About - String');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Displays this about dialog. Performs no function when set from within your code.');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('ConnectionName - String');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Name of the DUN connection to run.');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Name - String');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Name of this component, ie RunDUNConnection1.');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Tag - LongInt');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Components Tag.');

AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Events');
AboutIOPort.Memo.Lines.Add('_______________________________________________');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('');

AboutIOPort.Memo.Lines.Add('Methods');
AboutIOPort.Memo.Lines.Add('_______________________________________________');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Execute: Boolean - Function');
AboutIOPort.Memo.Lines.Add('');
AboutIOPort.Memo.Lines.Add('Runs the DUN Connection in ConnectionName. Returns True is successful, or False if not.');

  { Set result to OK }
    AboutIOPort.Icon := Application.Icon;
    AboutIOPort.ShowModal;

AboutIOPort.Free
end;



function TAboutTypeProperty.GetValue: string;
begin
Result := 'RunDUNConnection';
end;

procedure TAboutTypeProperty.SetValue(const Value: string);
begin
RunAboutBox;
end;

procedure TAboutTypeProperty.Edit;
begin
RunAboutBox;
end;

function TAboutTypeProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;



end.
